@@ -111,7 +111,7 @@ impl PkgConfig {
         }
 
         let libs = vec![
-            format!("-L{}", libdir.display()),
+            format!("-L{}", canonicalize(libdir.display().to_string())),
             format!("-l{}", capi_config.library.name),
         ];
 
@@ -282,6 +282,7 @@ mod test {
                     subdirectory: "".into(),
                     generation: true,
                     enabled: true,
+                    emit_version_constants: true,
                 },
                 pkg_config: crate::build::PkgConfigCApiConfig {
                     name: "foo".into(),
